import * as React from 'react';
import { Table, Header, Container, Form, Checkbox, Button } from 'semantic-ui-react';
import { ProbeDetails } from './ProbeDetails';
import { ListContainer } from './commons/ListContainer';

export class Probes extends React.Component<any, any> {

  private data: any;

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      selected: null,
      isDetail: false,
      list: [],
    };
  }

  componentWillMount() {
    this.data = [
      {
        "id": "11",
        "metaProbeStatus": {
          "name": "STARTED"
        },
        "domain": {
          "name": "asus"
        },
        "probeKey": "AGBLKDFJ2452ASDGFL2KWJLKSDJ",
        "description": "description1111111111",
      },
      {
        "id": "22",
        "metaProbeStatus": {
          "name": "STOPPED"
        },
        "domain": {
          "name": "ottugi"
        },
        "probeKey": "AGBLKDFJ2452ASDGFL2KWJLKSDJ",
        "description": "description22222222",
      },
      {
        "id": "33",
        "metaProbeStatus": {
          "name": "STOPPED"
        },
        "domain": {
          "name": "lg"
        },
        "probeKey": "AGBLKDFJ2452ASDGFL2KWJLKSDJ",
        "description": "description33333",
      },
      {
        "id": "44",
        "metaProbeStatus": {
          "name": "STARTED"
        },
        "domain": {
          "name": "apple"
        },
        "probeKey": "AGBLKDFJ2452ASDGFL2KWJLKSDJ",
        "description": "description4444",
      },
    ];
    this.setState({
      list: this.data,
    });
  }

  checkCellStatus(status: any): boolean {
    if (status.name === 'STOPPED') {
      return true;
    }
    return false;
  }

  handleSelect(selectedProbe: object) {
    this.setState({
      selected: selectedProbe,
      isDetail: true,
    });
  }

  handleSearch(searchWord: string) {
    console.log(searchWord);
    let founds = new Array();
    for (let probe of this.data) {
      if (probe.domain.name.toLowerCase().indexOf(searchWord) !== -1
        || probe.description.toLowerCase().indexOf(searchWord) !== -1
        || probe.metaProbeStatus.name.toLowerCase().indexOf(searchWord) !== -1) {
        founds.push(probe);
      }
    }
    this.setState({
      list: founds,
    });
  }

  handleFilter(filterStr: string) {
    if (filterStr === null) {
      this.setState({
        list: this.data,
      });
      return;
    }
    let founds = new Array();
    for (let probe of this.data) {
      if (probe.metaProbeStatus.name.indexOf(filterStr) !== -1) {
        founds.push(probe);
      }
    }
    this.setState({
      list: founds,
    });
  }

  render() {
    if (this.state.isDetail) {
      return <ProbeDetails probe={this.state.selected} onBack={() => this.setState({ isDetail: false })} />;
    }
    let probeList =
      <Container fluid>
        <Table selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>CIDR</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Status</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Target Count</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Sensor Count</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.state.list.map((probe: any, index: number) => (
              <Table.Row key={index} onClick={this.handleSelect.bind(this, probe)}>
                <Table.Cell >{probe.domain.name}</Table.Cell>
                <Table.Cell>{index}</Table.Cell>
                <Table.Cell negative={this.checkCellStatus(probe.metaProbeStatus)} textAlign={'center'}>{probe.metaProbeStatus.name}</Table.Cell>
                <Table.Cell textAlign={'center'} >todo. {probe.targetCnt}</Table.Cell>
                <Table.Cell textAlign={'center'} >todo. {probe.sensorCnt}</Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
      </Container>;

    return (
      <ListContainer
        contents={probeList}
        filter={<ProbeFilter data={this.data} onFilter={this.handleFilter.bind(this)} />}
        onSearch={this.handleSearch.bind(this)}
      />
    );
  }
}

export class ProbeFilter extends React.Component<any, any> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      status: null,
    };
  }

  handleChange(e: any, data: any) {
    this.setState({
      status: data.value,
    });
    this.props.onFilter(data.value);
  }
  handleReset(e: any, data: any) {
    this.setState({
      status: null,
    });
    this.props.onFilter(null);
  }

  render() {
    //todo. getting MetaProbeStatus
    let metaProbeStatus = [
      {
        "id": "1",
        "name": "STARTED",
      },
      {
        "id": "2",
        "name": "STOPPED",
      },
    ];
    return (
      <Form>
        <Container fluid>
          <Button size='mini' floated='right' basic content='Reset' onClick={this.handleReset.bind(this)} />
          <Form.Field>
            <b>Status</b>
          </Form.Field>

          {metaProbeStatus.map((item: any, index: number) => (
            <Form.Field key={index}>
              <Checkbox
                radio
                label={item.name}
                name='status'
                value={item.name}
                checked={this.state.status === item.name}
                onChange={this.handleChange.bind(this)}
              />
            </Form.Field>
          ))}
        </Container>
      </Form>
    );
  }
}



